spacepy.seapy.seadict — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- SeaPy - Superposed Epoch in Python »

# spacepy.seapy.seadict

`spacepy.seapy.` `seadict`(objlist, namelist)

  Function to create dictionary of SeaPy.Sea objects.

  Parameters: | - objlist: List of Sea objects. : namelist: List of variable labels for input objects.
  Other Parameters:
  | namelist = List containing names for y-axes. :

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- SeaPy - Superposed Epoch in Python »